/** Discord Epoch */
export declare const DISCORD_EPOCH = 1420070400000n;
export interface SnowflakeOptions {
    timestamp: number;
    workerId: number;
    processId: number;
    increment: number;
}
/** Class representing a Discord snowflake ID */
export declare class Snowflake {
    /**
     * @param {bigint} id - Discord snowflake ID
     */
    constructor(id: bigint | number | string);
    private readonly snowflake;
    /**
     * Generate Discord snowflake ID from timestamp, worker id, process id and increment
    */
    static construct({ timestamp, workerId, processId, increment }: SnowflakeOptions): Snowflake;
    /**
     * Timestamp in milliseconds
    */
    get timestamp(): number;
    /**
        * Internal worker ID
    */
    get workerId(): number;
    /**
     * Internal process ID
     */
    get processId(): number;
    /**
     * Increment
     */
    get increment(): number;
    /**
     * Date object from timestamp
     */
    get date(): Date;
}
