"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Snowflake = exports.DISCORD_EPOCH = void 0;
/** Discord Epoch */
exports.DISCORD_EPOCH = 1420070400000n;
/** Class representing a Discord snowflake ID */
class Snowflake {
    /**
     * @param {bigint} id - Discord snowflake ID
     */
    constructor(id) {
        this.snowflake = BigInt(id);
    }
    /**
     * Generate Discord snowflake ID from timestamp, worker id, process id and increment
    */
    static construct({ timestamp, workerId, processId, increment }) {
        const timestampPart = (timestamp << 22);
        const workerIdPart = (workerId << 17) | timestampPart;
        const processIdPart = (processId << 12) | workerIdPart;
        const snowflake = processIdPart | increment;
        return new Snowflake(snowflake);
    }
    /**
     * Timestamp in milliseconds
    */
    get timestamp() {
        return Number((BigInt(this.snowflake) >> BigInt(22)) + exports.DISCORD_EPOCH);
    }
    /**
        * Internal worker ID
    */
    get workerId() {
        return Number((BigInt(this.snowflake) & BigInt(0x3E0000)) >> BigInt(17));
    }
    /**
     * Internal process ID
     */
    get processId() {
        return Number((BigInt(this.snowflake) & BigInt(0x1F000)) >> BigInt(12));
    }
    /**
     * Increment
     */
    get increment() {
        return Number(BigInt(this.snowflake) & BigInt(0xFFF));
    }
    /**
     * Date object from timestamp
     */
    get date() {
        return new Date(this.timestamp);
    }
}
exports.Snowflake = Snowflake;
